@@ -24,13 +24,16 @@ import secrets
 import threading
 from collections import OrderedDict
 from enum import Enum
-from typing import Any, Callable, Final, Literal
+from typing import TYPE_CHECKING, Any, Final, Literal
 
 from blinker import Signal
 
 from streamlit import config_util, development, env_util, file_util, util
 from streamlit.config_option import ConfigOption
-from streamlit.errors import StreamlitAPIException
+from streamlit.errors import StreamlitAPIException, StreamlitInvalidThemeSectionError
+
+if TYPE_CHECKING:
+    from collections.abc import Callable
 
 # Config System Global State #
 
@@ -98,6 +101,10 @@ class CustomThemeCategories(str, Enum):
     """Theme categories that can be set with custom theme config."""
 
     SIDEBAR = "sidebar"
+    LIGHT = "light"
+    DARK = "dark"
+    LIGHT_SIDEBAR = "light.sidebar"
+    DARK_SIDEBAR = "dark.sidebar"
 
 
 def set_option(key: str, value: Any, where_defined: str = _USER_DEFINED) -> None:
@@ -323,6 +330,8 @@ def _create_theme_options(
     The same config option can be supported for multiple categories, e.g. "theme"
     and "theme.sidebar".
     """
+    # Handle creation of the main theme config sections (e.g. theme, theme.sidebar, theme.light, theme.dark)
+    # as well as the nested subsections (e.g. theme.light.sidebar, theme.dark.sidebar)
     for cat in categories:
         section = cat if cat == "theme" else f"theme.{cat.value}"
 
@@ -1045,8 +1054,8 @@ def _browser_server_port() -> int:
 
 _SSL_PRODUCTION_WARNING = [
     "DO NOT USE THIS OPTION IN A PRODUCTION ENVIRONMENT. It has not gone through "
-    "security audits or performance tests. For the production environment, "
-    "we recommend performing SSL termination by the load balancer or the reverse proxy."
+    "security audits or performance tests. For a production environment, we "
+    "recommend performing SSL termination through a load balancer or reverse proxy."
 ]
 
 _create_option(
@@ -1148,24 +1157,66 @@ _create_section("theme", "Settings to define a custom theme for your Streamlit a
 
 # Create a section for each custom theme element
 for cat in list(CustomThemeCategories):
-    _create_section(
-        f"theme.{cat.value}",
-        f"Settings to define a custom {cat.value} theme in your Streamlit app.",
-    )
+    if cat == CustomThemeCategories.SIDEBAR:
+        _create_section(
+            f"theme.{cat.value}",
+            f"Settings to define a custom {cat.value} theme in your Streamlit app.",
+        )
+    elif cat == CustomThemeCategories.LIGHT:
+        _create_section(
+            f"theme.{cat.value}",
+            "Settings to define custom light theme properties that extend the defined [theme] properties.",
+        )
+    elif cat == CustomThemeCategories.DARK:
+        _create_section(
+            f"theme.{cat.value}",
+            "Settings to define custom dark theme properties that extend the defined [theme] properties.",
+        )
+
+    # Create nested sidebar sections
+    elif cat == CustomThemeCategories.LIGHT_SIDEBAR:
+        _create_section(
+            f"theme.{cat.value}",
+            """Settings to define custom light theme properties for the sidebar that extend the defined
+            [theme.sidebar] properties.""",
+        )
+    elif cat == CustomThemeCategories.DARK_SIDEBAR:
+        _create_section(
+            f"theme.{cat.value}",
+            """Settings to define custom dark theme properties for the sidebar that extend the defined
+            [theme.sidebar] properties.""",
+        )
 
 _create_theme_options(
     "base",
     categories=["theme"],
     description="""
-        The preset Streamlit theme that your custom theme inherits from.
+        The theme that your custom theme inherits from.
 
-        This can be one of the following: "light" or "dark".
+        This can be one of the following:
+        - "light": Streamlit's default light theme.
+        - "dark": Streamlit's default dark theme.
+        - A local file path to a TOML theme file: A local custom theme, like
+          "themes/custom.toml".
+        - A URL to a TOML theme file: An externally hosted custom theme, like
+          "https://example.com/theme.toml".
+
+        A TOML theme file must contain a [theme] table with theme options.
+        Any theme options defined in the app's config.toml file will override
+        those defined in the TOML theme file.
     """,
 )
 
 _create_theme_options(
     "primaryColor",
-    categories=["theme", CustomThemeCategories.SIDEBAR],
+    categories=[
+        "theme",
+        CustomThemeCategories.SIDEBAR,
+        CustomThemeCategories.LIGHT,
+        CustomThemeCategories.DARK,
+        CustomThemeCategories.LIGHT_SIDEBAR,
+        CustomThemeCategories.DARK_SIDEBAR,
+    ],
     description="""
         Primary accent color.
     """,
@@ -1173,7 +1224,14 @@ _create_theme_options(
 
 _create_theme_options(
     "backgroundColor",
-    categories=["theme", CustomThemeCategories.SIDEBAR],
+    categories=[
+        "theme",
+        CustomThemeCategories.SIDEBAR,
+        CustomThemeCategories.LIGHT,
+        CustomThemeCategories.DARK,
+        CustomThemeCategories.LIGHT_SIDEBAR,
+        CustomThemeCategories.DARK_SIDEBAR,
+    ],
     description="""
         Background color of the app.
     """,
@@ -1181,7 +1239,14 @@ _create_theme_options(
 
 _create_theme_options(
     "secondaryBackgroundColor",
-    categories=["theme", CustomThemeCategories.SIDEBAR],
+    categories=[
+        "theme",
+        CustomThemeCategories.SIDEBAR,
+        CustomThemeCategories.LIGHT,
+        CustomThemeCategories.DARK,
+        CustomThemeCategories.LIGHT_SIDEBAR,
+        CustomThemeCategories.DARK_SIDEBAR,
+    ],
     description="""
         Background color used for most interactive widgets.
     """,
@@ -1189,7 +1254,14 @@ _create_theme_options(
 
 _create_theme_options(
     "textColor",
-    categories=["theme", CustomThemeCategories.SIDEBAR],
+    categories=[
+        "theme",
+        CustomThemeCategories.SIDEBAR,
+        CustomThemeCategories.LIGHT,
+        CustomThemeCategories.DARK,
+        CustomThemeCategories.LIGHT_SIDEBAR,
+        CustomThemeCategories.DARK_SIDEBAR,
+    ],
     description="""
         Color used for almost all text.
     """,
@@ -1197,7 +1269,14 @@ _create_theme_options(
 
 _create_theme_options(
     "redColor",
-    categories=["theme", CustomThemeCategories.SIDEBAR],
+    categories=[
+        "theme",
+        CustomThemeCategories.SIDEBAR,
+        CustomThemeCategories.LIGHT,
+        CustomThemeCategories.DARK,
+        CustomThemeCategories.LIGHT_SIDEBAR,
+        CustomThemeCategories.DARK_SIDEBAR,
+    ],
     description="""
         Red color used in the basic color palette.
 
@@ -1212,7 +1291,14 @@ _create_theme_options(
 
 _create_theme_options(
     "orangeColor",
-    categories=["theme", CustomThemeCategories.SIDEBAR],
+    categories=[
+        "theme",
+        CustomThemeCategories.SIDEBAR,
+        CustomThemeCategories.LIGHT,
+        CustomThemeCategories.DARK,
+        CustomThemeCategories.LIGHT_SIDEBAR,
+        CustomThemeCategories.DARK_SIDEBAR,
+    ],
     description="""
         Orange color used in the basic color palette.
 
@@ -1227,7 +1313,14 @@ _create_theme_options(
 
 _create_theme_options(
     "yellowColor",
-    categories=["theme", CustomThemeCategories.SIDEBAR],
+    categories=[
+        "theme",
+        CustomThemeCategories.SIDEBAR,
+        CustomThemeCategories.LIGHT,
+        CustomThemeCategories.DARK,
+        CustomThemeCategories.LIGHT_SIDEBAR,
+        CustomThemeCategories.DARK_SIDEBAR,
+    ],
     description="""
         Yellow color used in the basic color palette.
 
@@ -1242,7 +1335,14 @@ _create_theme_options(
 
 _create_theme_options(
     "blueColor",
-    categories=["theme", CustomThemeCategories.SIDEBAR],
+    categories=[
+        "theme",
+        CustomThemeCategories.SIDEBAR,
+        CustomThemeCategories.LIGHT,
+        CustomThemeCategories.DARK,
+        CustomThemeCategories.LIGHT_SIDEBAR,
+        CustomThemeCategories.DARK_SIDEBAR,
+    ],
     description="""
         Blue color used in the basic color palette.
 
@@ -1257,7 +1357,14 @@ _create_theme_options(
 
 _create_theme_options(
     "greenColor",
-    categories=["theme", CustomThemeCategories.SIDEBAR],
+    categories=[
+        "theme",
+        CustomThemeCategories.SIDEBAR,
+        CustomThemeCategories.LIGHT,
+        CustomThemeCategories.DARK,
+        CustomThemeCategories.LIGHT_SIDEBAR,
+        CustomThemeCategories.DARK_SIDEBAR,
+    ],
     description="""
         Green color used in the basic color palette.
 
@@ -1272,7 +1379,14 @@ _create_theme_options(
 
 _create_theme_options(
     "violetColor",
-    categories=["theme", CustomThemeCategories.SIDEBAR],
+    categories=[
+        "theme",
+        CustomThemeCategories.SIDEBAR,
+        CustomThemeCategories.LIGHT,
+        CustomThemeCategories.DARK,
+        CustomThemeCategories.LIGHT_SIDEBAR,
+        CustomThemeCategories.DARK_SIDEBAR,
+    ],
     description="""
         Violet color used in the basic color palette.
 
@@ -1286,7 +1400,14 @@ _create_theme_options(
 
 _create_theme_options(
     "grayColor",
-    categories=["theme", CustomThemeCategories.SIDEBAR],
+    categories=[
+        "theme",
+        CustomThemeCategories.SIDEBAR,
+        CustomThemeCategories.LIGHT,
+        CustomThemeCategories.DARK,
+        CustomThemeCategories.LIGHT_SIDEBAR,
+        CustomThemeCategories.DARK_SIDEBAR,
+    ],
     description="""
         Gray color used in the basic color palette.
 
@@ -1301,7 +1422,14 @@ _create_theme_options(
 
 _create_theme_options(
     "redBackgroundColor",
-    categories=["theme", CustomThemeCategories.SIDEBAR],
+    categories=[
+        "theme",
+        CustomThemeCategories.SIDEBAR,
+        CustomThemeCategories.LIGHT,
+        CustomThemeCategories.DARK,
+        CustomThemeCategories.LIGHT_SIDEBAR,
+        CustomThemeCategories.DARK_SIDEBAR,
+    ],
     description="""
         Red background color used in the basic color palette.
 
@@ -1315,7 +1443,14 @@ _create_theme_options(
 
 _create_theme_options(
     "orangeBackgroundColor",
-    categories=["theme", CustomThemeCategories.SIDEBAR],
+    categories=[
+        "theme",
+        CustomThemeCategories.SIDEBAR,
+        CustomThemeCategories.LIGHT,
+        CustomThemeCategories.DARK,
+        CustomThemeCategories.LIGHT_SIDEBAR,
+        CustomThemeCategories.DARK_SIDEBAR,
+    ],
     description="""
         Orange background color used for the basic color palette.
 
@@ -1329,7 +1464,14 @@ _create_theme_options(
 
 _create_theme_options(
     "yellowBackgroundColor",
-    categories=["theme", CustomThemeCategories.SIDEBAR],
+    categories=[
+        "theme",
+        CustomThemeCategories.SIDEBAR,
+        CustomThemeCategories.LIGHT,
+        CustomThemeCategories.DARK,
+        CustomThemeCategories.LIGHT_SIDEBAR,
+        CustomThemeCategories.DARK_SIDEBAR,
+    ],
     description="""
         Yellow background color used for the basic color palette.
 
@@ -1343,7 +1485,14 @@ _create_theme_options(
 
 _create_theme_options(
     "blueBackgroundColor",
-    categories=["theme", CustomThemeCategories.SIDEBAR],
+    categories=[
+        "theme",
+        CustomThemeCategories.SIDEBAR,
+        CustomThemeCategories.LIGHT,
+        CustomThemeCategories.DARK,
+        CustomThemeCategories.LIGHT_SIDEBAR,
+        CustomThemeCategories.DARK_SIDEBAR,
+    ],
     description="""
         Blue background color used for the basic color palette.
 
@@ -1357,7 +1506,14 @@ _create_theme_options(
 
 _create_theme_options(
     "greenBackgroundColor",
-    categories=["theme", CustomThemeCategories.SIDEBAR],
+    categories=[
+        "theme",
+        CustomThemeCategories.SIDEBAR,
+        CustomThemeCategories.LIGHT,
+        CustomThemeCategories.DARK,
+        CustomThemeCategories.LIGHT_SIDEBAR,
+        CustomThemeCategories.DARK_SIDEBAR,
+    ],
     description="""
         Green background color used for the basic color palette.
 
@@ -1371,7 +1527,14 @@ _create_theme_options(
 
 _create_theme_options(
     "violetBackgroundColor",
-    categories=["theme", CustomThemeCategories.SIDEBAR],
+    categories=[
+        "theme",
+        CustomThemeCategories.SIDEBAR,
+        CustomThemeCategories.LIGHT,
+        CustomThemeCategories.DARK,
+        CustomThemeCategories.LIGHT_SIDEBAR,
+        CustomThemeCategories.DARK_SIDEBAR,
+    ],
     description="""
         Violet background color used for the basic color palette.
 
@@ -1385,7 +1548,14 @@ _create_theme_options(
 
 _create_theme_options(
     "grayBackgroundColor",
-    categories=["theme", CustomThemeCategories.SIDEBAR],
+    categories=[
+        "theme",
+        CustomThemeCategories.SIDEBAR,
+        CustomThemeCategories.LIGHT,
+        CustomThemeCategories.DARK,
+        CustomThemeCategories.LIGHT_SIDEBAR,
+        CustomThemeCategories.DARK_SIDEBAR,
+    ],
     description="""
         Gray background color used for the basic color palette.
 
@@ -1399,7 +1569,14 @@ _create_theme_options(
 
 _create_theme_options(
     "redTextColor",
-    categories=["theme", CustomThemeCategories.SIDEBAR],
+    categories=[
+        "theme",
+        CustomThemeCategories.SIDEBAR,
+        CustomThemeCategories.LIGHT,
+        CustomThemeCategories.DARK,
+        CustomThemeCategories.LIGHT_SIDEBAR,
+        CustomThemeCategories.DARK_SIDEBAR,
+    ],
     description="""
         Red text color used for the basic color palette.
 
@@ -1413,7 +1590,14 @@ _create_theme_options(
 
 _create_theme_options(
     "orangeTextColor",
-    categories=["theme", CustomThemeCategories.SIDEBAR],
+    categories=[
+        "theme",
+        CustomThemeCategories.SIDEBAR,
+        CustomThemeCategories.LIGHT,
+        CustomThemeCategories.DARK,
+        CustomThemeCategories.LIGHT_SIDEBAR,
+        CustomThemeCategories.DARK_SIDEBAR,
+    ],
     description="""
         Orange text color used for the basic color palette.
 
@@ -1427,7 +1611,14 @@ _create_theme_options(
 
 _create_theme_options(
     "yellowTextColor",
-    categories=["theme", CustomThemeCategories.SIDEBAR],
+    categories=[
+        "theme",
+        CustomThemeCategories.SIDEBAR,
+        CustomThemeCategories.LIGHT,
+        CustomThemeCategories.DARK,
+        CustomThemeCategories.LIGHT_SIDEBAR,
+        CustomThemeCategories.DARK_SIDEBAR,
+    ],
     description="""
         Yellow text color used for the basic color palette.
 
@@ -1441,7 +1632,14 @@ _create_theme_options(
 
 _create_theme_options(
     "blueTextColor",
-    categories=["theme", CustomThemeCategories.SIDEBAR],
+    categories=[
+        "theme",
+        CustomThemeCategories.SIDEBAR,
+        CustomThemeCategories.LIGHT,
+        CustomThemeCategories.DARK,
+        CustomThemeCategories.LIGHT_SIDEBAR,
+        CustomThemeCategories.DARK_SIDEBAR,
+    ],
     description="""
         Blue text color used for the basic color palette.
 
@@ -1455,7 +1653,14 @@ _create_theme_options(
 
 _create_theme_options(
     "greenTextColor",
-    categories=["theme", CustomThemeCategories.SIDEBAR],
+    categories=[
+        "theme",
+        CustomThemeCategories.SIDEBAR,
+        CustomThemeCategories.LIGHT,
+        CustomThemeCategories.DARK,
+        CustomThemeCategories.LIGHT_SIDEBAR,
+        CustomThemeCategories.DARK_SIDEBAR,
+    ],
     description="""
         Green text color used for the basic color palette.
 
@@ -1469,7 +1674,14 @@ _create_theme_options(
 
 _create_theme_options(
     "violetTextColor",
-    categories=["theme", CustomThemeCategories.SIDEBAR],
+    categories=[
+        "theme",
+        CustomThemeCategories.SIDEBAR,
+        CustomThemeCategories.LIGHT,
+        CustomThemeCategories.DARK,
+        CustomThemeCategories.LIGHT_SIDEBAR,
+        CustomThemeCategories.DARK_SIDEBAR,
+    ],
     description="""
         Violet text color used for the basic color palette.
 
@@ -1483,7 +1695,14 @@ _create_theme_options(
 
 _create_theme_options(
     "grayTextColor",
-    categories=["theme", CustomThemeCategories.SIDEBAR],
+    categories=[
+        "theme",
+        CustomThemeCategories.SIDEBAR,
+        CustomThemeCategories.LIGHT,
+        CustomThemeCategories.DARK,
+        CustomThemeCategories.LIGHT_SIDEBAR,
+        CustomThemeCategories.DARK_SIDEBAR,
+    ],
     description="""
         Gray text color used for the basic color palette.
 
@@ -1497,24 +1716,64 @@ _create_theme_options(
 
 _create_theme_options(
     "linkColor",
-    categories=["theme", CustomThemeCategories.SIDEBAR],
+    categories=[
+        "theme",
+        CustomThemeCategories.SIDEBAR,
+        CustomThemeCategories.LIGHT,
+        CustomThemeCategories.DARK,
+        CustomThemeCategories.LIGHT_SIDEBAR,
+        CustomThemeCategories.DARK_SIDEBAR,
+    ],
     description="""
         Color used for all links.
+
+        This defaults to the resolved value of `blueTextColor`.
     """,
 )
 
 _create_theme_options(
     "linkUnderline",
-    categories=["theme", CustomThemeCategories.SIDEBAR],
+    categories=[
+        "theme",
+        CustomThemeCategories.SIDEBAR,
+        CustomThemeCategories.LIGHT,
+        CustomThemeCategories.DARK,
+        CustomThemeCategories.LIGHT_SIDEBAR,
+        CustomThemeCategories.DARK_SIDEBAR,
+    ],
     description="""
         Whether or not links should be displayed with an underline.
     """,
     type_=bool,
 )
 
+_create_theme_options(
+    "codeTextColor",
+    categories=[
+        "theme",
+        CustomThemeCategories.SIDEBAR,
+        CustomThemeCategories.LIGHT,
+        CustomThemeCategories.DARK,
+        CustomThemeCategories.LIGHT_SIDEBAR,
+        CustomThemeCategories.DARK_SIDEBAR,
+    ],
+    description="""
+        Text color used for code blocks.
+
+        This defaults to the resolved value of `greenTextColor`.
+    """,
+)
+
 _create_theme_options(
     "codeBackgroundColor",
-    categories=["theme", CustomThemeCategories.SIDEBAR],
+    categories=[
+        "theme",
+        CustomThemeCategories.SIDEBAR,
+        CustomThemeCategories.LIGHT,
+        CustomThemeCategories.DARK,
+        CustomThemeCategories.LIGHT_SIDEBAR,
+        CustomThemeCategories.DARK_SIDEBAR,
+    ],
     description="""
         Background color used for code blocks.
     """,
@@ -1522,7 +1781,14 @@ _create_theme_options(
 
 _create_theme_options(
     "font",
-    categories=["theme", CustomThemeCategories.SIDEBAR],
+    categories=[
+        "theme",
+        CustomThemeCategories.SIDEBAR,
+        CustomThemeCategories.LIGHT,
+        CustomThemeCategories.DARK,
+        CustomThemeCategories.LIGHT_SIDEBAR,
+        CustomThemeCategories.DARK_SIDEBAR,
+    ],
     description="""
         The font family for all text, except code blocks.
 
@@ -1603,7 +1869,14 @@ _create_theme_options(
 
 _create_theme_options(
     "headingFont",
-    categories=["theme", CustomThemeCategories.SIDEBAR],
+    categories=[
+        "theme",
+        CustomThemeCategories.SIDEBAR,
+        CustomThemeCategories.LIGHT,
+        CustomThemeCategories.DARK,
+        CustomThemeCategories.LIGHT_SIDEBAR,
+        CustomThemeCategories.DARK_SIDEBAR,
+    ],
     description="""
         The font family to use for headings.
 
@@ -1623,7 +1896,14 @@ _create_theme_options(
 
 _create_theme_options(
     "headingFontSizes",
-    categories=["theme", CustomThemeCategories.SIDEBAR],
+    categories=[
+        "theme",
+        CustomThemeCategories.SIDEBAR,
+        CustomThemeCategories.LIGHT,
+        CustomThemeCategories.DARK,
+        CustomThemeCategories.LIGHT_SIDEBAR,
+        CustomThemeCategories.DARK_SIDEBAR,
+    ],
     description="""
         One or more font sizes for h1-h6 headings.
 
@@ -1655,7 +1935,14 @@ _create_theme_options(
 
 _create_theme_options(
     "headingFontWeights",
-    categories=["theme", CustomThemeCategories.SIDEBAR],
+    categories=[
+        "theme",
+        CustomThemeCategories.SIDEBAR,
+        CustomThemeCategories.LIGHT,
+        CustomThemeCategories.DARK,
+        CustomThemeCategories.LIGHT_SIDEBAR,
+        CustomThemeCategories.DARK_SIDEBAR,
+    ],
     description="""
         One or more font weights for h1-h6 headings.
 
@@ -1685,7 +1972,14 @@ _create_theme_options(
 
 _create_theme_options(
     "codeFont",
-    categories=["theme", CustomThemeCategories.SIDEBAR],
+    categories=[
+        "theme",
+        CustomThemeCategories.SIDEBAR,
+        CustomThemeCategories.LIGHT,
+        CustomThemeCategories.DARK,
+        CustomThemeCategories.LIGHT_SIDEBAR,
+        CustomThemeCategories.DARK_SIDEBAR,
+    ],
     description="""
         The font family to use for code (monospace) in the sidebar.
 
@@ -1703,7 +1997,14 @@ _create_theme_options(
 
 _create_theme_options(
     "codeFontSize",
-    categories=["theme", CustomThemeCategories.SIDEBAR],
+    categories=[
+        "theme",
+        CustomThemeCategories.SIDEBAR,
+        CustomThemeCategories.LIGHT,
+        CustomThemeCategories.DARK,
+        CustomThemeCategories.LIGHT_SIDEBAR,
+        CustomThemeCategories.DARK_SIDEBAR,
+    ],
     description="""
         The font size (in pixels or rem) for code blocks and code text.
 
@@ -1716,7 +2017,14 @@ _create_theme_options(
 
 _create_theme_options(
     "codeFontWeight",
-    categories=["theme", CustomThemeCategories.SIDEBAR],
+    categories=[
+        "theme",
+        CustomThemeCategories.SIDEBAR,
+        CustomThemeCategories.LIGHT,
+        CustomThemeCategories.DARK,
+        CustomThemeCategories.LIGHT_SIDEBAR,
+        CustomThemeCategories.DARK_SIDEBAR,
+    ],
     description="""
         The font weight for code blocks and code text.
 
@@ -1731,7 +2039,14 @@ _create_theme_options(
 
 _create_theme_options(
     "baseRadius",
-    categories=["theme", CustomThemeCategories.SIDEBAR],
+    categories=[
+        "theme",
+        CustomThemeCategories.SIDEBAR,
+        CustomThemeCategories.LIGHT,
+        CustomThemeCategories.DARK,
+        CustomThemeCategories.LIGHT_SIDEBAR,
+        CustomThemeCategories.DARK_SIDEBAR,
+    ],
     description="""
         The radius used as basis for the corners of most UI elements.
 
@@ -1750,7 +2065,14 @@ _create_theme_options(
 
 _create_theme_options(
     "buttonRadius",
-    categories=["theme", CustomThemeCategories.SIDEBAR],
+    categories=[
+        "theme",
+        CustomThemeCategories.SIDEBAR,
+        CustomThemeCategories.LIGHT,
+        CustomThemeCategories.DARK,
+        CustomThemeCategories.LIGHT_SIDEBAR,
+        CustomThemeCategories.DARK_SIDEBAR,
+    ],
     description="""
         The radius used as basis for the corners of buttons.
 
@@ -1771,7 +2093,14 @@ _create_theme_options(
 
 _create_theme_options(
     "borderColor",
-    categories=["theme", CustomThemeCategories.SIDEBAR],
+    categories=[
+        "theme",
+        CustomThemeCategories.SIDEBAR,
+        CustomThemeCategories.LIGHT,
+        CustomThemeCategories.DARK,
+        CustomThemeCategories.LIGHT_SIDEBAR,
+        CustomThemeCategories.DARK_SIDEBAR,
+    ],
     description="""
         The color of the border around elements.
     """,
@@ -1779,7 +2108,14 @@ _create_theme_options(
 
 _create_theme_options(
     "dataframeBorderColor",
-    categories=["theme", CustomThemeCategories.SIDEBAR],
+    categories=[
+        "theme",
+        CustomThemeCategories.SIDEBAR,
+        CustomThemeCategories.LIGHT,
+        CustomThemeCategories.DARK,
+        CustomThemeCategories.LIGHT_SIDEBAR,
+        CustomThemeCategories.DARK_SIDEBAR,
+    ],
     description="""
         The color of the border around dataframes and tables.
 
@@ -1789,7 +2125,14 @@ _create_theme_options(
 
 _create_theme_options(
     "dataframeHeaderBackgroundColor",
-    categories=["theme", CustomThemeCategories.SIDEBAR],
+    categories=[
+        "theme",
+        CustomThemeCategories.SIDEBAR,
+        CustomThemeCategories.LIGHT,
+        CustomThemeCategories.DARK,
+        CustomThemeCategories.LIGHT_SIDEBAR,
+        CustomThemeCategories.DARK_SIDEBAR,
+    ],
     description="""
         The background color of the dataframe's header.
 
@@ -1803,7 +2146,14 @@ _create_theme_options(
 
 _create_theme_options(
     "showWidgetBorder",
-    categories=["theme", CustomThemeCategories.SIDEBAR],
+    categories=[
+        "theme",
+        CustomThemeCategories.SIDEBAR,
+        CustomThemeCategories.LIGHT,
+        CustomThemeCategories.DARK,
+        CustomThemeCategories.LIGHT_SIDEBAR,
+        CustomThemeCategories.DARK_SIDEBAR,
+    ],
     description="""
         Whether to show a border around input widgets.
     """,
@@ -2043,6 +2393,43 @@ def _update_config_with_sensitive_env_var(
         _set_option(opt_name, env_var_value, _DEFINED_BY_ENV_VAR)
 
 
+def _is_valid_theme_section(section_path: str) -> bool:
+    """Check if a theme section path follows valid nesting rules, returns True if valid, False otherwise.
+
+    Valid patterns: theme.sidebar, theme.light, theme.dark, theme.light.sidebar, theme.dark.sidebar
+    Invalid patterns: theme.sidebar.light, theme.sidebar.dark, theme.light.dark, theme.dark.light, etc.
+
+    Parameters
+    ----------
+    section_path : str
+        The dot-separated theme section path (e.g., "theme.light.sidebar").
+        Will always have at least 2 parts and start with "theme".
+    """
+    parts = section_path.split(".")
+
+    # theme.sidebar/light/dark is valid (2 parts: "theme" + section)
+    if len(parts) == 2:
+        return parts[1] in [
+            CustomThemeCategories.SIDEBAR.value,
+            CustomThemeCategories.LIGHT.value,
+            CustomThemeCategories.DARK.value,
+        ]
+
+    # theme.light.sidebar/theme.dark.sidebar are the only valid 3-part patterns
+    if len(parts) == 3:
+        # Only allow light/dark as the middle level, with sidebar as the final level
+        if parts[1] in [
+            CustomThemeCategories.LIGHT.value,
+            CustomThemeCategories.DARK.value,
+        ]:
+            return parts[2] == CustomThemeCategories.SIDEBAR.value
+        # sidebar cannot have nested sections (theme.sidebar.light/dark)
+        return False
+
+    # Any nesting with 4+ parts is invalid (e.g., theme.light.sidebar.dark)
+    return False
+
+
 def _update_config_with_toml(raw_toml: str, where_defined: str) -> None:
     """Update the config system by parsing this string.
 
@@ -2105,8 +2492,17 @@ def _update_config_with_toml(raw_toml: str, where_defined: str) -> None:
 
         for name, value in section_data.items():
             option_name = f"{section_path}.{name}"
-            # Process it as a nested config section if it's a custom theme sub-category
-            if name in [CustomThemeCategories.SIDEBAR.value]:
+            # Only check for nested sections when we're already in a theme section
+            if section_path.startswith("theme") and name in [
+                CustomThemeCategories.SIDEBAR.value,
+                CustomThemeCategories.LIGHT.value,
+                CustomThemeCategories.DARK.value,
+            ]:
+                # Validate the theme section before processing
+                if not _is_valid_theme_section(option_name):
+                    raise StreamlitInvalidThemeSectionError(
+                        option_name=option_name,
+                    )
                 process_section(option_name, value)
             else:
                 # It's a regular config option, set it
@@ -2257,6 +2653,13 @@ def get_config_options(
         for opt_name, opt_val in options_from_flags.items():
             _set_option(opt_name, opt_val, _DEFINED_BY_FLAG)
 
+        # Handle theme inheritance if theme.base points to a file
+        # This happens AFTER all config sources (files, env vars, flags) are processed
+        # so theme.base can be set via any of those
+        config_util.process_theme_inheritance(
+            _config_options, _config_options_template, _set_option
+        )
+
         if old_options and config_util.server_option_changed(
             old_options, _config_options
         ):
