@@ -42,7 +42,7 @@ from streamlit.elements.lib.column_config_utils import (
 )
 from streamlit.elements.lib.form_utils import current_form_id
 from streamlit.elements.lib.layout_utils import (
-    HeightWithoutContent,
+    Height,
     LayoutConfig,
     Width,
     validate_height,
@@ -287,7 +287,7 @@ class ArrowMixin:
         self,
         data: Data = None,
         width: Width = "stretch",
-        height: HeightWithoutContent | Literal["auto"] = "auto",
+        height: Height | Literal["auto"] = "auto",
         *,
         use_container_width: bool | None = None,
         hide_index: bool | None = None,
@@ -297,6 +297,7 @@ class ArrowMixin:
         on_select: Literal["ignore"] = "ignore",
         selection_mode: SelectionMode | Iterable[SelectionMode] = "multi-row",
         row_height: int | None = None,
+        placeholder: str | None = None,
     ) -> DeltaGenerator: ...
 
     @overload
@@ -304,7 +305,7 @@ class ArrowMixin:
         self,
         data: Data = None,
         width: Width = "stretch",
-        height: HeightWithoutContent | Literal["auto"] = "auto",
+        height: Height | Literal["auto"] = "auto",
         *,
         use_container_width: bool | None = None,
         hide_index: bool | None = None,
@@ -314,6 +315,7 @@ class ArrowMixin:
         on_select: Literal["rerun"] | WidgetCallback,
         selection_mode: SelectionMode | Iterable[SelectionMode] = "multi-row",
         row_height: int | None = None,
+        placeholder: str | None = None,
     ) -> DataframeState: ...
 
     @gather_metrics("dataframe")
@@ -321,7 +323,7 @@ class ArrowMixin:
         self,
         data: Data = None,
         width: Width = "stretch",
-        height: HeightWithoutContent | Literal["auto"] = "auto",
+        height: Height | Literal["auto"] = "auto",
         *,
         use_container_width: bool | None = None,
         hide_index: bool | None = None,
@@ -331,6 +333,7 @@ class ArrowMixin:
         on_select: Literal["ignore", "rerun"] | WidgetCallback = "ignore",
         selection_mode: SelectionMode | Iterable[SelectionMode] = "multi-row",
         row_height: int | None = None,
+        placeholder: str | None = None,
     ) -> DeltaGenerator | DataframeState:
         """Display a dataframe as an interactive table.
 
@@ -389,11 +392,14 @@ class ArrowMixin:
               the parent container, the width of the element matches the width
               of the parent container.
 
-        height : "auto", "stretch", or int
+        height : "auto", "content", "stretch", or int
             The height of the dataframe element. This can be one of the following:
 
             - ``"auto"`` (default): Streamlit sets the height to show at most
               ten rows.
+            - ``"content"``: The height of the element matches the height of
+              its content. The height is capped at 10,000 pixels to prevent
+              performance issues with very large dataframes.
             - ``"stretch"``: The height of the element expands to fill the
               available vertical space in its parent container. When multiple
               elements with stretch height are in the same container, they
@@ -510,6 +516,12 @@ class ArrowMixin:
             is ``None`` (default), Streamlit will use a default row height,
             which fits one line of text.
 
+        placeholder : str or None
+            The text that should be shown for missing values. If this is
+            ``None`` (default), missing values are displayed as "None". To
+            leave a cell empty, use an empty string (``""``). Other common
+            values are ``"null"``, ``"NaN"`` and ``"-"``.
+
         Returns
         -------
         element or dict
@@ -676,7 +688,7 @@ class ArrowMixin:
         validate_width(width, allow_content=True)
         validate_height(
             height,
-            allow_content=False,
+            allow_content=True,
             additional_allowed=["auto"],
         )
 
@@ -691,6 +703,9 @@ class ArrowMixin:
         if column_order:
             proto.column_order[:] = column_order
 
+        if placeholder is not None:
+            proto.placeholder = placeholder
+
         proto.editing_mode = ArrowProto.EditingMode.READ_ONLY
 
         has_range_index: bool = False
@@ -767,6 +782,7 @@ class ArrowMixin:
                 selection_mode=selection_mode,
                 is_selection_activated=is_selection_activated,
                 row_height=row_height,
+                placeholder=placeholder,
             )
 
             serde = DataframeSelectionSerde()
@@ -895,6 +911,12 @@ class ArrowMixin:
     def add_rows(self, data: Data = None, **kwargs: Any) -> DeltaGenerator | None:
         """Concatenate a dataframe to the bottom of the current one.
 
+        .. important::
+            ``add_rows`` is deprecated and might be removed in a future version.
+            If you have a specific use-case that requires the ``add_rows``
+            functionality, please tell us via this
+            [issue on Github](https://github.com/streamlit/streamlit/issues/13063).
+
         Parameters
         ----------
         data : pandas.DataFrame, pandas.Styler, pyarrow.Table, numpy.ndarray, pyspark.sql.DataFrame, snowflake.snowpark.dataframe.DataFrame, Iterable, dict, or None
@@ -947,6 +969,14 @@ class ArrowMixin:
         >>> my_chart.add_rows(some_fancy_name=df2)  # <-- name used as keyword
 
         """  # noqa: E501
+        show_deprecation_warning(
+            "`add_rows` is deprecated and might be removed in a future version."
+            " If you have a specific use-case that requires the `add_rows` "
+            "functionality, please tell us via this "
+            "[issue on Github](https://github.com/streamlit/streamlit/issues/13063).",
+            show_in_browser=False,
+        )
+
         return _arrow_add_rows(self.dg, data, **kwargs)
 
     @property
