@@ -19,15 +19,13 @@ from textwrap import dedent
 from typing import (
     TYPE_CHECKING,
     Any,
-    Callable,
     Generic,
+    TypeGuard,
     TypeVar,
     cast,
     overload,
 )
 
-from typing_extensions import TypeGuard
-
 from streamlit.dataframe_util import OptionSequence, convert_anything_to_list
 from streamlit.elements.lib.form_utils import current_form_id
 from streamlit.elements.lib.layout_utils import LayoutConfig, validate_width
@@ -61,7 +59,7 @@ from streamlit.runtime.state import (
 from streamlit.type_util import check_python_comparable
 
 if TYPE_CHECKING:
-    from collections.abc import Sequence
+    from collections.abc import Callable, Sequence
 
     from streamlit.delta_generator import DeltaGenerator
     from streamlit.elements.lib.layout_utils import WidthWithoutContent
@@ -264,6 +262,8 @@ class SelectSliderMixin:
             The current value of the slider widget. The return type will match
             the data type of the value parameter.
 
+            This contains copies of the selected options, not the originals.
+
         Examples
         --------
         >>> import streamlit as st
@@ -377,7 +377,10 @@ class SelectSliderMixin:
         element_id = compute_and_register_element_id(
             "select_slider",
             user_key=key,
-            key_as_main_identity=False,
+            # Treat the provided key as the main identity; only include
+            # changes to the options (and implicitly their formatting) in the
+            # identity computation as those can invalidate the current value.
+            key_as_main_identity={"options", "format_func"},
             dg=self.dg,
             label=label,
             options=[str(format_func(option)) for option in opt],
