@@ -247,8 +247,6 @@ class Credentials:
                     "`streamlit activate reset` then `streamlit activate`"
                 )
         else:
-            if not config.get_option("server.showEmailPrompt"):
-                return
             activated = False
 
             while not activated:
@@ -345,9 +343,11 @@ def check_credentials() -> None:
     check, since credential would be automatically set to an empty string.
 
     """
-    from streamlit import config
 
-    if not _check_credential_file_exists() and config.get_option("server.headless"):
+    if not _check_credential_file_exists() and (
+        config.get_option("server.headless")
+        or not config.get_option("server.showEmailPrompt")
+    ):
         if not config.is_manually_set("browser.gatherUsageStats"):
             # If not manually defined, show short message about usage stats gathering.
             cli_util.print_to_cli(_TELEMETRY_HEADLESS_TEXT)
