@@ -48,6 +48,7 @@ from streamlit.testing.v1.element_tree import (
     Column,
     Dataframe,
     DateInput,
+    DateTimeInput,
     Divider,
     ElementList,
     ElementTree,
@@ -608,6 +609,20 @@ class AppTest:
         """
         return self._tree.date_input
 
+    @property
+    def datetime_input(self) -> WidgetList[DateTimeInput]:
+        """Sequence of all ``st.datetime_input`` widgets.
+
+        Returns
+        -------
+        WidgetList of DateTimeInput
+            Sequence of all ``st.datetime_input`` widgets. Individual widgets can
+            be accessed from a WidgetList by index (order on the page) or key.
+            For example, ``at.datetime_input[0]`` for the first widget or
+            ``at.datetime_input(key="my_key")`` for a widget with a given key.
+        """
+        return self._tree.datetime_input
+
     @property
     def divider(self) -> ElementList[Divider]:
         """Sequence of all ``st.divider`` elements.
