@@ -40,6 +40,7 @@ from streamlit.elements.widgets.select_slider import SelectSliderSerde
 from streamlit.elements.widgets.slider import SliderSerde, SliderStep
 from streamlit.elements.widgets.time_widgets import (
     DateInputSerde,
+    DateTimeInputSerde,
     DateWidgetReturn,
     TimeInputSerde,
     _parse_date_value,
@@ -62,6 +63,7 @@ if TYPE_CHECKING:
     from streamlit.proto.Code_pb2 import Code as CodeProto
     from streamlit.proto.ColorPicker_pb2 import ColorPicker as ColorPickerProto
     from streamlit.proto.DateInput_pb2 import DateInput as DateInputProto
+    from streamlit.proto.DateTimeInput_pb2 import DateTimeInput as DateTimeInputProto
     from streamlit.proto.Element_pb2 import Element as ElementProto
     from streamlit.proto.Exception_pb2 import Exception as ExceptionProto
     from streamlit.proto.ForwardMsg_pb2 import ForwardMsg
@@ -1323,6 +1325,7 @@ class TextInput(Widget):
 
 
 TimeValue: TypeAlias = time | datetime
+DateTimeWidgetValue: TypeAlias = datetime
 
 
 @dataclass(repr=False)
@@ -1382,6 +1385,59 @@ class TimeInput(Widget):
         return self.set_value(dt.time())
 
 
+@dataclass(repr=False)
+class DateTimeInput(Widget):
+    """A representation of ``st.datetime_input``."""
+
+    _value: DateTimeWidgetValue | None | InitialValue
+    proto: DateTimeInputProto = field(repr=False)
+    label: str
+    format: str
+    min: str
+    max: str
+    step: int
+    help: str
+    form_id: str
+
+    def __init__(self, proto: DateTimeInputProto, root: ElementTree) -> None:
+        super().__init__(proto, root)
+        self._value = InitialValue()
+        self.type = "date_time_input"
+
+    def set_value(self, v: DateTimeWidgetValue | None) -> DateTimeInput:
+        """Set the value of the widget."""
+        self._value = v
+        return self
+
+    @property
+    def _widget_state(self) -> WidgetState:
+        from datetime import datetime
+
+        datetime_ui_format = "%Y/%m/%d, %H:%M"
+
+        ws = WidgetState()
+        ws.id = self.id
+
+        # Parse min and max values for validation
+        min_dt = datetime.strptime(self.min, datetime_ui_format)
+        max_dt = datetime.strptime(self.max, datetime_ui_format)
+
+        serde = DateTimeInputSerde(value=None, min=min_dt, max=max_dt)
+        serialized_value = serde.serialize(self.value)
+        if serialized_value is not None:
+            ws.string_array_value.data[:] = serialized_value
+        return ws
+
+    @property
+    def value(self) -> datetime | None:
+        """The current value of the widget. (datetime)"""  # noqa: D400
+        if not isinstance(self._value, InitialValue):
+            return self._value
+        state = self.root.session_state
+        assert state
+        return state[self.id]  # type: ignore
+
+
 @dataclass(repr=False)
 class Toast(Element):
     proto: ToastProto = field(repr=False)
@@ -1532,6 +1588,10 @@ class Block:
     def date_input(self) -> WidgetList[DateInput]:
         return WidgetList(self.get("date_input"))  # type: ignore
 
+    @property
+    def datetime_input(self) -> WidgetList[DateTimeInput]:
+        return WidgetList(self.get("date_time_input"))  # type: ignore
+
     @property
     def divider(self) -> ElementList[Divider]:
         return ElementList(self.get("divider"))  # type: ignore
@@ -1986,6 +2046,8 @@ def parse_tree_from_messages(messages: list[ForwardMsg]) -> ElementTree:
                 new_node = ColorPicker(elt.color_picker, root=root)
             elif ty == "date_input":
                 new_node = DateInput(elt.date_input, root=root)
+            elif ty == "date_time_input":
+                new_node = DateTimeInput(elt.date_time_input, root=root)
             elif ty == "exception":
                 new_node = Exception(elt.exception, root=root)
             elif ty == "heading":
